""" Contains a list of manual translations. Those are usually messages that
exist in external packages which provide no translations.

"""

from onegov.town import _

# messages defined in wtforms-components
_("Not a valid color.")
