/*
    Adds support for bright primary colors.
*/
$anchor-font-color: $primary-color;
$crumb-font-color: $primary-color;
$side-nav-link-color: $primary-color;
$side-nav-link-color-active: #333;
$side-nav-link-color-hover: #333;

@if lightness($primary-color) >= 50% {
    $anchor-font-color: scale-color($anchor-font-color, $lightness: -40%, $saturation: +10%);
    $crumb-font-color: scale-color($crumb-font-color, $lightness: -40%, $saturation: +10%);
    $side-nav-link-color: scale-color($side-nav-link-color, $lightness: -40%, $saturation: +10%);
}
